@@ -52,7 +52,8 @@ class ConnectableClient:
     def __init__(self) -> None:
         self.last_event_arg = None
 
-    # A client must implement QI, and respond to a query for the Event interface.
+    # A client must implement QI, and respond to a query for the Event
+    # interface.
     # In addition, it must provide a COM object (which server.util.wrap) does.
     def _query_interface_(self, iid):  # noqa: ANN202
         import win32com.server.util
@@ -81,7 +82,7 @@ def CheckEvent(server, client, val, verbose) -> None:
 # A simple test script for all this.
 # In the real world, it is likely that the code controlling the server
 # will be in the same class as that getting the notifications.
-def test(verbose=0) -> None:
+def simple_test(verbose=0) -> None:
     import win32com.client.connect
     import win32com.client.dynamic
     import win32com.server.policy
@@ -104,4 +105,4 @@ def test(verbose=0) -> None:
 
 
 if __name__ == "__main__":
-    test(1)
+    simple_test(1)
