@@ -10,6 +10,12 @@
 #include <windows.h>
 #include <winsvc.h>
 
+#include "pythoncapi_compat.h"
+
+extern PyStatus InitializePython(int argc, wchar_t** argv);
+extern int ExecuteScript(void);
+extern PyStatus get_program_name(wchar_t** ptr_str, wchar_t* argv0);
+
 // define constants
 #define CX_LOGGING_SECTION_NAME      L"Logging"
 #define CX_LOGGING_FILE_NAME_KEY     L"FileName"
@@ -51,26 +57,15 @@ static PyInterpreterState* gInterpreterState = NULL;
 static PyObject* gInstance = NULL;
 static wchar_t gIniFileName[MAXPATHLEN + 1];
 
-//-----------------------------------------------------------------------------
-// FatalError()
-//   Called when an attempt to initialize the module zip fails.
-//-----------------------------------------------------------------------------
-static int FatalError(const char* message)
-{
-    return LogPythonException(message);
-}
-
 //-----------------------------------------------------------------------------
 // FatalScriptError()
 //   Called when an attempt to import the initscript fails.
 //-----------------------------------------------------------------------------
-static int FatalScriptError(void)
+int FatalScriptError(void)
 {
     return LogPythonException("initialization script didn't execute properly");
 }
 
-#include "common.c"
-
 //-----------------------------------------------------------------------------
 // Service_SetStatus()
 //   Set the status for the service.
@@ -212,9 +207,12 @@ static int Service_StartLogging(void)
     unsigned logLevel, maxFiles, maxFileSize;
     wchar_t *executable, *ptr, prefix[CX_LOGGING_PREFIX_SIZE];
     size_t size;
+    PyStatus status;
 
     // determine the default log file name and ini file name
-    executable = get_executable_name();
+    status = get_program_name(&executable, NULL);
+    if (PyStatus_Exception(status))
+        return LogPythonException(status.err_msg);
     ptr = wcsrchr(executable, '.');
     if (ptr)
         size = ptr - executable;
@@ -264,7 +262,7 @@ static int Service_SetupPython(udt_ServiceInfo* info)
         Service_SetStatus(info, SERVICE_STOPPED);
         return -1;
     }
-    gInterpreterState = threadState->interp;
+    gInterpreterState = PyThreadState_GetInterpreter(threadState);
     PyThreadState_Swap(threadState);
 
     // running base script
@@ -298,7 +296,7 @@ static int Service_SetupPython(udt_ServiceInfo* info)
     temp = PyObject_GetAttrString(module, CX_SERVICE_AUTO_START);
     if (!temp)
         PyErr_Clear();
-    else if (temp == Py_True)
+    else if (Py_IsTrue(temp))
         info->startType = SERVICE_AUTO_START;
 
     // determine if service should monitor session changes (optional)
@@ -306,7 +304,7 @@ static int Service_SetupPython(udt_ServiceInfo* info)
     temp = PyObject_GetAttrString(module, CX_SERVICE_SESSION_CHANGES);
     if (!temp)
         PyErr_Clear();
-    else if (temp == Py_True)
+    else if (Py_IsTrue(temp))
         info->sessionChanges = 1;
 
     // import the module which implements the service
@@ -344,10 +342,14 @@ static int Service_Install(
     SC_HANDLE managerHandle, serviceHandle;
     SERVICE_DESCRIPTIONW sd;
     udt_ServiceInfo info;
+    PyStatus status;
 
     // initialize Python
-    if (InitializePython(argc, argv) < 0)
+    status = InitializePython(argc, argv);
+    if (PyStatus_Exception(status)) {
+        LogPythonException(status.err_msg);
         return 1;
+    }
 
     // set up Python
     if (Service_SetupPython(&info) < 0)
@@ -370,7 +372,9 @@ static int Service_Install(
     Py_CLEAR(nameObj);
 
     // determine command to use for the service
-    executable = get_executable_name();
+    status = get_program_name(&executable, NULL);
+    if (PyStatus_Exception(status))
+        return LogPythonException(status.err_msg);
     executableNameObj = PyUnicode_FromWideChar(executable, -1);
     if (!executableNameObj)
         return LogPythonException("cannot create executable name obj");
@@ -462,8 +466,11 @@ static int Service_Uninstall(wchar_t* name, int argc, wchar_t** argv)
     udt_ServiceInfo info;
 
     // initialize Python
-    if (InitializePython(argc, argv) < 0)
+    PyStatus status = InitializePython(argc, argv);
+    if (PyStatus_Exception(status)) {
+        LogPythonException(status.err_msg);
         return 1;
+    }
 
     // set up Python
     if (Service_SetupPython(&info) < 0)
@@ -557,8 +564,11 @@ static void WINAPI Service_Main(int argc, wchar_t** argv)
     udt_ServiceInfo info;
 
     // initialize Python
-    if (InitializePython(argc, argv) < 0)
+    PyStatus status = InitializePython(argc, argv);
+    if (PyStatus_Exception(status)) {
+        LogPythonException(status.err_msg);
         return;
+    }
 
     if (Service_SetupPython(&info) < 0)
         return;
