@@ -3,29 +3,25 @@
 from __future__ import annotations
 
 import os
-from pathlib import Path
 
 import pytest
-from generate_samples import SUB_PACKAGE_TEST, create_package, run_command
 from setuptools import Distribution
 
-from cx_Freeze._compat import BUILD_EXE_DIR, EXE_SUFFIX, IS_WINDOWS
+from cx_Freeze._compat import BUILD_EXE_DIR, IS_WINDOWS
 from cx_Freeze.command.build_exe import build_exe
 from cx_Freeze.exception import SetupError
-from cx_Freeze.executable import Executable
 
-SAMPLES_DIR = Path(__file__).resolve().parent.parent / "samples"
+from .datatest import SUB_PACKAGE_TEST
+
 BUILD_EXE_CMD = "python setup.py build_exe --silent --excludes=tkinter"
 
-OUTPUT1 = "Hello from cx_Freeze Advanced #1\nTest freeze module #1\n"
-OUTPUT2 = "Hello from cx_Freeze Advanced #2\nTest freeze module #2\n"
-
-OUTPUT_SUBPACKAGE_TEST = "This is p.p1\nThis is p.q.q1\n"
+OUTPUT0 = "Hello from cx_Freeze Advanced #{}"
+OUTPUT1 = "Test freeze module #{}"
 
 DIST_ATTRS = {
     "name": "foo",
     "version": "0.0",
-    "executables": [Executable("hello.py")],
+    "executables": ["hello.py"],
     "script_name": "setup.py",
 }
 
@@ -364,71 +360,59 @@ def test_build_exe_script_args(
         assert getattr(cmd_obj, option) == value
 
 
-@pytest.mark.datafiles(SAMPLES_DIR / "advanced")
-def test_build_exe_advanced(datafiles: Path) -> None:
+def test_build_exe_advanced(tmp_package) -> None:
     """Test the advanced sample."""
-    output = run_command(
-        datafiles, "python setup.py build_exe --silent --excludes=tkinter"
-    )
+    tmp_package.create_from_sample("advanced")
+    tmp_package.freeze("python setup.py build_exe --silent --excludes=tkinter")
 
-    executable = datafiles / BUILD_EXE_DIR / f"advanced_1{EXE_SUFFIX}"
+    executable = tmp_package.executable("advanced_1")
     assert executable.is_file()
-    output = run_command(datafiles, executable, timeout=10)
-    assert output == OUTPUT1
+    result = tmp_package.run(executable, timeout=10)
+    result.stdout.fnmatch_lines([OUTPUT0.format(1), OUTPUT1.format(1)])
 
-    executable = datafiles / BUILD_EXE_DIR / f"advanced_2{EXE_SUFFIX}"
+    executable = tmp_package.executable("advanced_2")
     assert executable.is_file()
-    output = run_command(datafiles, executable, timeout=10)
-    assert output == OUTPUT2
+    result = tmp_package.run(executable, timeout=10)
+    result.stdout.fnmatch_lines([OUTPUT0.format(2), OUTPUT1.format(2)])
 
 
-@pytest.mark.datafiles(SAMPLES_DIR / "asmodule")
-def test_build_exe_asmodule(datafiles: Path) -> None:
+def test_build_exe_asmodule(tmp_package) -> None:
     """Test the asmodule sample."""
-    output = run_command(datafiles, BUILD_EXE_CMD)
+    tmp_package.create_from_sample("asmodule")
+    tmp_package.freeze(BUILD_EXE_CMD)
 
-    executable = datafiles / BUILD_EXE_DIR / f"asmodule{EXE_SUFFIX}"
+    executable = tmp_package.executable("asmodule")
     assert executable.is_file()
-    output = run_command(datafiles, executable, timeout=10)
-    assert output.startswith("Hello from cx_Freeze")
+    result = tmp_package.run(executable, timeout=10)
+    result.stdout.fnmatch_lines("Hello from cx_Freeze")
 
 
-@pytest.mark.datafiles(SAMPLES_DIR / "sqlite")
-def test_build_exe_sqlite(datafiles: Path) -> None:
-    """Test the sqlite sample."""
-    output = run_command(datafiles, BUILD_EXE_CMD)
-
-    executable = datafiles / BUILD_EXE_DIR / f"test_sqlite3{EXE_SUFFIX}"
-    assert executable.is_file()
-    output = run_command(datafiles, executable, timeout=10)
-    assert output.startswith("dump.sql created")
+OUTPUT_SUBPACKAGE_TEST = ["This is p.p1", "This is p.q.q1"]
 
 
-def test_zip_include_packages(tmp_path) -> None:
+def test_zip_include_packages(tmp_package) -> None:
     """Test the simple sample with zip_include_packages option."""
     source = SUB_PACKAGE_TEST[4]
-    create_package(tmp_path, source)
-    output = run_command(
-        tmp_path,
+    tmp_package.create(source)
+    tmp_package.freeze(
         f"{BUILD_EXE_CMD} --zip-exclude-packages=* --zip-include-packages=p",
     )
 
-    executable = tmp_path / BUILD_EXE_DIR / f"main{EXE_SUFFIX}"
+    executable = tmp_package.executable("main")
     assert executable.is_file()
-    output = run_command(tmp_path, executable, timeout=10)
-    assert output == OUTPUT_SUBPACKAGE_TEST
+    result = tmp_package.run(executable, timeout=10)
+    result.stdout.fnmatch_lines(OUTPUT_SUBPACKAGE_TEST)
 
 
-def test_zip_exclude_packages(tmp_path) -> None:
+def test_zip_exclude_packages(tmp_package) -> None:
     """Test the simple sample with zip_exclude_packages option."""
     source = SUB_PACKAGE_TEST[4]
-    create_package(tmp_path, source)
-    output = run_command(
-        tmp_path,
+    tmp_package.create(source)
+    tmp_package.freeze(
         f"{BUILD_EXE_CMD} --zip-exclude-packages=p --zip-include-packages=*",
     )
 
-    executable = tmp_path / BUILD_EXE_DIR / f"main{EXE_SUFFIX}"
+    executable = tmp_package.executable("main")
     assert executable.is_file()
-    output = run_command(tmp_path, executable, timeout=10)
-    assert output == OUTPUT_SUBPACKAGE_TEST
+    result = tmp_package.run(executable, timeout=10)
+    result.stdout.fnmatch_lines(OUTPUT_SUBPACKAGE_TEST)
