@@ -11,7 +11,7 @@ import pytest
 from setuptools import Distribution
 
 from cx_Freeze import Executable
-from cx_Freeze._compat import EXE_SUFFIX, IS_MINGW, IS_WINDOWS, SOABI
+from cx_Freeze._compat import EXE_SUFFIX, IS_CONDA, IS_MINGW, IS_WINDOWS, SOABI
 from cx_Freeze.exception import OptionError, SetupError
 
 SOURCE_SETUP_TOML = """
@@ -31,6 +31,7 @@ pyproject.toml
     target_name = "test_2"
 
     [tool.cxfreeze.build_exe]
+    include_msvcr = true
     excludes = ["tkinter", "unittest"]
     silent = true
 command
@@ -48,15 +49,22 @@ setup.py
         {"script": "test_1.py", "target_name": "test_2"},
         Executable("test_1.py", target_name="test_3"),
     ]
-
+    options = {
+        "build_exe": {
+            "include_msvcr": True,
+            "excludes": ["tkinter", "unittest"],
+            "silent": True
+        }
+    }
     setup(
         name="hello",
         version="0.1.2.3",
         description="Sample cx_Freeze script",
         executables=executables,
+        options=options,
     )
 command
-    python setup.py build_exe --excludes=tkinter,unittest --silent
+    python setup.py build_exe
 """
 
 SOURCE_SETUP_CFG = """
@@ -69,6 +77,7 @@ setup.cfg
     description = Sample cx_Freeze script
 
     [build_exe]
+    include_msvcr = true
     excludes = tkinter,unittest
     silent = true
 command
@@ -89,6 +98,7 @@ pyproject.toml
     target_name = "test_2"
 
     [tool.cxfreeze.build_exe]
+    include_msvcr = true
     excludes = ["tkinter", "unittest"]
     silent = true
 setup.py
@@ -135,6 +145,7 @@ pyproject.toml
     script = "test_3.py"
 
     [tool.cxfreeze.build_exe]
+    include_msvcr = true
     excludes = ["tkinter", "unittest"]
     silent = true
 command
@@ -166,6 +177,7 @@ setup.py
 
     options = {
         "build_exe": {
+            "include_msvcr": True,
             "excludes": ["tkinter", "unittest"],
             "include_path": ["."],
             "silent": True
@@ -208,14 +220,14 @@ def test_executables(
 ) -> None:
     """Test the executables option."""
     tmp_package.create(source)
-    output = tmp_package.run()
+    tmp_package.freeze()
 
     for i in range(1, number_of_executables):
         file_created = tmp_package.executable(f"test_{i}")
         assert file_created.is_file(), f"file not found: {file_created}"
 
-        output = tmp_package.run(file_created, timeout=10)
-        assert output.startswith("Hello from cx_Freeze")
+        result = tmp_package.run(file_created, timeout=10)
+        result.stdout.fnmatch_lines("Hello from cx_Freeze*")
 
 
 TEST_VALID_PARAMETERS = [
@@ -387,22 +399,22 @@ def test_valid_icon(tmp_package) -> None:
         shutil.copyfile(
             src, tmp_package.path.joinpath("icon").with_suffix(src.suffix)
         )
-    output = tmp_package.run()
-    assert "WARNING: Icon file not found" not in output, "icon file not found"
+    result = tmp_package.freeze()
+    result.stdout.no_fnmatch_line("WARNING: Icon file not found")
 
     file_created = tmp_package.executable("test_icon")
     assert file_created.is_file(), f"file not found: {file_created}"
 
-    output = tmp_package.run(file_created, timeout=10)
-    assert output.startswith("Hello from cx_Freeze")
+    result = tmp_package.run(file_created, timeout=10)
+    result.stdout.fnmatch_lines("Hello from cx_Freeze")
 
 
 def test_not_found_icon(tmp_package) -> None:
     """Test with not found icon in any OS."""
     # same test as before, without icons
     tmp_package.create(SOURCE_VALID_ICON)
-    output = tmp_package.run()
-    assert "WARNING: Icon file not found" in output, "icon file not found"
+    result = tmp_package.freeze()
+    result.stdout.fnmatch_lines("WARNING: Icon file not found: icon.svg")
 
 
 SOURCE_INVALID_ICON = """
@@ -431,10 +443,12 @@ def test_invalid_icon(tmp_package) -> None:
     # use an invalid icon: cp $SRC/cx_Freeze/icons/py.png $DST/icon.png
     src_dir = files("cx_Freeze").resolve()
     shutil.copyfile(src_dir / "icons/py.png", tmp_package.path / "icon.png")
-    output = tmp_package.run()
-    assert "WARNING: Icon file not found" not in output, "icon file not found"
-    # it is expected the folowing warning if the icon is invalid
-    assert "WARNING: Icon filename 'icon.png' has invalid type." in output
+    result = tmp_package.freeze()
+    result.stdout.no_fnmatch_line("WARNING: Icon file not found")
+    # it is expected the following warning if the icon is invalid
+    result.stdout.fnmatch_lines(
+        "WARNING: Icon filename 'icon.png' has invalid type."
+    )
 
 
 SOURCE_RENAME = """
@@ -458,16 +472,16 @@ pyproject.toml
 def test_executable_rename(tmp_package) -> None:
     """Test if the executable can be renamed."""
     tmp_package.create(SOURCE_RENAME)
-    output = tmp_package.run()
+    tmp_package.freeze()
     file_created = tmp_package.executable("test_0")
     assert file_created.is_file(), f"file not found: {file_created}"
 
-    output = tmp_package.run(file_created, timeout=10)
-    assert output.startswith("Hello from cx_Freeze")
+    result = tmp_package.run(file_created, timeout=10)
+    result.stdout.fnmatch_lines("Hello from cx_Freeze")
 
     file_renamed = file_created.rename(file_created.parent / "test_zero")
-    output = tmp_package.run(file_renamed, timeout=10)
-    assert output.startswith("Hello from cx_Freeze")
+    result = tmp_package.run(file_renamed, timeout=10)
+    result.stdout.fnmatch_lines("Hello from cx_Freeze")
 
 
 SOURCE_NAMESPACE = """\
@@ -487,7 +501,7 @@ main.py
 namespace/package/__init__.py
     print("Hello from cx_Freeze")
 command
-    cxfreeze --script main.py --target-name test --silent
+    cxfreeze --script main.py --target-name test --silent --include-msvcr
 """
 
 SOURCE_NESTED_NAMESPACE = """\
@@ -514,7 +528,7 @@ namespace/package/one.py
 namespace/package/two.py
     print("Hello from cx_Freeze - module two")
 command
-    cxfreeze --script main.py --target-name test --silent
+    cxfreeze --script main.py --target-name test --silent --include-msvcr
 """
 
 
@@ -546,22 +560,73 @@ def test_executable_namespace(
     if zip_packages:
         with tmp_package.path.joinpath("command").open("a") as f:
             f.write(" --zip-include-packages=* --zip-exclude-packages=")
-    output = tmp_package.run()
+    tmp_package.freeze()
 
     file_created = tmp_package.executable("test")
     assert file_created.is_file(), f"file not found: {file_created}"
 
-    output = tmp_package.run(file_created, timeout=10)
-    lines = output.splitlines()
+    result = tmp_package.run(file_created, timeout=10)
     start = 0
     stop = hello
-    for i in range(start, stop):
-        assert lines[i].startswith("Hello from cx_Freeze")
+    expected = ["Hello from cx_Freeze*" for _i in range(start, stop)]
+    result.stdout.fnmatch_lines(expected)
     start += hello
     stop += namespace
+    lines = result.outlines
     for i in range(start, stop):
         assert lines[i].endswith("True")
     start += namespace
     stop += package_or_module
     for i in range(start, stop):
         assert lines[i].endswith("False")
+
+
+SOURCE_VALID_SYS_PATH = """
+test_sys_path.py
+    import os
+    import sys
+    from pathlib import Path
+
+    def get_module_path_list(current_path):
+        parent_path = os.path.abspath(os.path.join(current_path, "modules"))
+        return [current_path, parent_path]
+
+    now_path = Path.cwd()
+
+    module_path_list = get_module_path_list(now_path)
+    sys.path.extend(module_path_list)
+
+    # import a package thas has modules in C/C++ or rust
+    import numpy
+    print("Hello from cx_Freeze")
+    print(f"{numpy.__name__} loaded!")
+pyproject.toml
+    [project]
+    name = "hello"
+    version = "0.1.2.3"
+    description = "Sample cx_Freeze script"
+    dependencies = ["numpy"]
+
+    [[tool.cxfreeze.executables]]
+    script = "test_sys_path.py"
+
+    [tool.cxfreeze.build_exe]
+    include_msvcr = true
+    excludes = ["tkinter", "unittest"]
+    silent = false
+"""
+
+
+@pytest.mark.skipif(IS_CONDA, reason="Disabled on conda-forge")
+@pytest.mark.skipif(IS_MINGW, reason="Disabled on msys2")
+@pytest.mark.venv
+def test_valid_sys_path(tmp_package) -> None:
+    """Test if sys.path has valid values."""
+    tmp_package.create(SOURCE_VALID_SYS_PATH)
+    tmp_package.freeze()
+
+    file_created = tmp_package.executable("test_sys_path")
+    assert file_created.is_file(), f"file not found: {file_created}"
+
+    result = tmp_package.run(file_created, timeout=10)
+    result.stdout.fnmatch_lines(["Hello from cx_Freeze", "numpy loaded!"])
