@@ -8,7 +8,7 @@ import sys
 
 import pytest
 
-from cx_Freeze._compat import IS_ARM_64, IS_MINGW, IS_WINDOWS
+from cx_Freeze._compat import IS_ARM_64, IS_CONDA, IS_MINGW, IS_WINDOWS
 from cx_Freeze.dep_parser import PEParser
 
 if sys.platform != "win32":
@@ -65,22 +65,23 @@ simple.manifest
 def test_manifest(tmp_package) -> None:
     """With the correct manifest, windows version return 10.0 in Windows 10."""
     tmp_package.create(SOURCE)
-    tmp_package.run()
+    tmp_package.freeze()
     executable = tmp_package.executable("test_manifest")
     assert executable.is_file()
-    output = tmp_package.run(executable, timeout=10)
+    result = tmp_package.run(executable, timeout=10)
     winver = sys.getwindowsversion()
     expected = f"Windows version: {winver.major}.{winver.minor}"
-    assert output.splitlines()[0].strip() == expected
+    result.stdout.fnmatch_lines(expected)
 
 
 LIEF_VERSIONS = []
 if IS_WINDOWS:
     if IS_ARM_64:
-        LIEF_VERSIONS += ["disabled"]
+        LIEF_VERSIONS += ["0.16.6"]
+    elif IS_CONDA:
+        LIEF_VERSIONS += ["installed"]
     else:
-        # use 0.16.4 to work with pypi and conda versions
-        LIEF_VERSIONS += ["0.15.1", "0.16.4"]
+        LIEF_VERSIONS += ["0.15.1", "0.16.6"]
 elif IS_MINGW:
     LIEF_VERSIONS += ["installed"]
 
@@ -101,15 +102,15 @@ def test_simple_manifest(tmp_package, lief_version) -> None:
             lief_version = "disabled"
     else:
         tmp_package.install(f"lief=={lief_version}")
-    tmp_package.run()
+    tmp_package.freeze()
     executable = tmp_package.executable("test_simple_manifest")
     assert executable.is_file()
-    output = tmp_package.run(executable, timeout=10)
+    result = tmp_package.run(executable, timeout=10)
     if lief_version == "disabled":
         expected = "Windows version: 10.0"
     else:
         expected = "Windows version: 6.2"
-    assert output.splitlines()[0].strip() == expected
+    result.stdout.fnmatch_lines(expected)
 
     parser = PEParser([], [])
     manifest = parser.read_manifest(executable)
@@ -129,7 +130,7 @@ def test_uac_admin(tmp_package, lief_version) -> None:
     tmp_package.create(SOURCE)
     if lief_version != "installed":
         tmp_package.install(f"lief=={lief_version}")
-    tmp_package.run()
+    tmp_package.freeze()
     executable = tmp_package.executable("test_uac_admin")
     assert executable.is_file()
     with pytest.raises(OSError, match="[WinError 740]"):
@@ -145,7 +146,7 @@ def test_uac_uiaccess(tmp_package, lief_version) -> None:
     tmp_package.create(SOURCE)
     if lief_version != "installed":
         tmp_package.install(f"lief=={lief_version}")
-    tmp_package.run()
+    tmp_package.freeze()
     executable = tmp_package.executable("test_uac_uiaccess")
     assert executable.is_file()
     with pytest.raises(OSError, match="[WinError 740]"):
